@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2014-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2014-2023 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: LGPL-2.1-or-later
 */
@@ -7,8 +7,10 @@
 #include "grantleethemetest.h"
 #include "grantleetheme.h"
 
+#include <QFile>
 #include <QPalette>
 #include <QProcess>
+#include <QRegularExpression>
 #include <QStandardPaths>
 #include <qtest.h>
 
@@ -22,14 +24,12 @@ GrantleeThemeTest::GrantleeThemeTest(QObject *parent)
     QStandardPaths::setTestModeEnabled(true);
 
     // Point the test to our dummy icon theme
-    KConfigGroup cg(KSharedConfig::openConfig(), "Icons");
+    KConfigGroup cg(KSharedConfig::openConfig(), QStringLiteral("Icons"));
     cg.writeEntry("Theme", "dummyTheme");
     qputenv("XDG_DATA_DIRS", GRANTLEETHEME_DATA_DIR);
 }
 
-GrantleeThemeTest::~GrantleeThemeTest()
-{
-}
+GrantleeThemeTest::~GrantleeThemeTest() = default;
 
 void GrantleeThemeTest::shouldHaveDefaultValue()
 {
@@ -96,7 +96,7 @@ bool GrantleeThemeTest::validateHtml(const QString &themePath, const QString &na
     const QString htmlFileName = themePath + QStringLiteral("/%1.out.html").arg(name);
     QFile outFile(outFileName);
     if (!outFile.open(QIODevice::WriteOnly)) {
-        qDebug() << "impossible to open " << outFile;
+        qDebug() << "impossible to open " << outFile.fileName();
         return false;
     }
     outFile.write(html.toUtf8());
@@ -124,7 +124,7 @@ bool GrantleeThemeTest::compareHtml(const QString &generatedTheme, const QString
         }
         QString content = QString::fromUtf8(f.readAll());
         f.close();
-        content.replace(QRegExp(QLatin1String("\"file:[^\"]*[/(?:%2F)]([^\"/(?:%2F)]*)\"")), QStringLiteral("\"file:\\1\""));
+        content.replace(QRegularExpression(QLatin1String("\"file:[^\"]*[/(?:%2F)]([^\"/(?:%2F)]*)\"")), QStringLiteral("\"file:\\1\""));
         if (!f.open(QIODevice::WriteOnly | QIODevice::Truncate)) {
             return false;
         }
@@ -198,3 +198,5 @@ void GrantleeThemeTest::testRenderTemplate()
 }
 
 QTEST_GUILESS_MAIN(GrantleeThemeTest)
+
+#include "moc_grantleethemetest.cpp"
