@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2013-2023 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: LGPL-2.1-or-later
 */
@@ -21,7 +21,7 @@
 using namespace GrantleeTheme;
 
 QSharedPointer<GrantleeKi18nLocalizer> GrantleeTheme::ThemePrivate::sLocalizer;
-Grantlee::Engine *GrantleeTheme::ThemePrivate::sEngine = nullptr;
+KTextTemplate::Engine *GrantleeTheme::ThemePrivate::sEngine = nullptr;
 
 ThemePrivate::ThemePrivate()
     : QSharedData()
@@ -29,22 +29,10 @@ ThemePrivate::ThemePrivate()
 }
 
 ThemePrivate::ThemePrivate(const ThemePrivate &other)
-    : QSharedData(other)
-    , displayExtraVariables(other.displayExtraVariables)
-    , themeFileName(other.themeFileName)
-    , description(other.description)
-    , name(other.name)
-    , dirName(other.dirName)
-    , absolutePaths(other.absolutePaths)
-    , author(other.author)
-    , email(other.email)
-    , loader(other.loader)
-{
-}
 
-ThemePrivate::~ThemePrivate()
-{
-}
+    = default;
+
+ThemePrivate::~ThemePrivate() = default;
 
 void ThemePrivate::setupEngine()
 {
@@ -56,12 +44,11 @@ void ThemePrivate::setupLoader()
     // Get the parent dir with themes, we set the theme directory separately
 
     QStringList templatePaths;
-    for (const QString &absolutePath : qAsConst(absolutePaths)) {
+    for (const QString &absolutePath : std::as_const(absolutePaths)) {
         QDir dir(absolutePath);
         dir.cdUp();
         templatePaths << dir.absolutePath();
     }
-
     loader = QSharedPointer<GrantleeTheme::QtResourceTemplateLoader>::create();
     loader->setTemplateDirs(templatePaths);
     loader->setTheme(dirName);
@@ -71,27 +58,25 @@ void ThemePrivate::setupLoader()
     }
     sEngine->addTemplateLoader(loader);
 }
-
-Grantlee::Context ThemePrivate::createContext(const QVariantHash &data, const QByteArray &applicationDomain)
+KTextTemplate::Context ThemePrivate::createContext(const QVariantHash &data, const QByteArray &applicationDomain)
 {
     if (!sLocalizer) {
         sLocalizer.reset(new GrantleeKi18nLocalizer());
     }
     sLocalizer->setApplicationDomain(applicationDomain);
-    Grantlee::Context ctx(data);
+    KTextTemplate::Context ctx(data);
     ctx.setLocalizer(sLocalizer);
     return ctx;
 }
-
-QString ThemePrivate::errorTemplate(const QString &reason, const QString &origTemplateName, const Grantlee::Template &failedTemplate)
+QString ThemePrivate::errorTemplate(const QString &reason, const QString &origTemplateName, const KTextTemplate::Template &failedTemplate)
 {
-    Grantlee::Template tpl = sEngine->newTemplate(QStringLiteral("<h1>{{ error }}</h1>\n"
-                                                                 "<b>%1:</b> {{ templateName }}<br>\n"
-                                                                 "<b>%2:</b> {{ errorMessage }}")
-                                                      .arg(i18n("Template"), i18n("Error message")),
-                                                  QStringLiteral("TemplateError"));
+    KTextTemplate::Template tpl = sEngine->newTemplate(QStringLiteral("<h1>{{ error }}</h1>\n"
+                                                                      "<b>%1:</b> {{ templateName }}<br>\n"
+                                                                      "<b>%2:</b> {{ errorMessage }}")
+                                                           .arg(i18n("Template"), i18n("Error message")),
+                                                       QStringLiteral("TemplateError"));
 
-    Grantlee::Context ctx = createContext();
+    KTextTemplate::Context ctx = createContext();
     ctx.insert(QStringLiteral("error"), reason);
     ctx.insert(QStringLiteral("templateName"), origTemplateName);
     const QString errorString = failedTemplate ? failedTemplate->errorString() : i18n("(null template)");
@@ -121,13 +106,10 @@ Theme::Theme(const QString &themePath, const QString &dirName, const QString &de
 }
 
 Theme::Theme(const Theme &other)
-    : d(other.d)
-{
-}
 
-Theme::~Theme()
-{
-}
+    = default;
+
+Theme::~Theme() = default;
 
 bool Theme::operator==(const Theme &other) const
 {
@@ -206,15 +188,13 @@ QString Theme::render(const QString &templateName, const QVariantHash &data, con
     if (!d->loader->canLoadTemplate(templateName)) {
         qCWarning(GRANTLEETHEME_LOG) << "Cannot load template" << templateName
                                      << ", please check your installation. Tried in these dirs:" << d->loader->templateDirs();
-        return QString();
+        return {};
     }
-
-    Grantlee::Template tpl = d->loader->loadByName(templateName, ThemePrivate::sEngine);
+    KTextTemplate::Template tpl = d->loader->loadByName(templateName, ThemePrivate::sEngine);
     if (!tpl || tpl->error()) {
         return d->errorTemplate(i18n("Template parsing error"), templateName, tpl);
     }
-
-    Grantlee::Context ctx = d->createContext(data, applicationDomain);
+    KTextTemplate::Context ctx = d->createContext(data, applicationDomain);
     const QString result = tpl->render(&ctx);
     if (tpl->error()) {
         return d->errorTemplate(i18n("Template rendering error"), templateName, tpl);
