@@ -22,21 +22,13 @@ public:
 };
 
 Engine::Engine(QObject *parent)
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    : Grantlee::Engine(parent)
-#else
     : KTextTemplate::Engine(parent)
-#endif
     , d(new GrantleeTheme::EnginePrivate)
 {
     addPluginPath(QStringLiteral(GRANTLEE_PLUGIN_INSTALL_DIR));
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    addDefaultLibrary(QStringLiteral("grantlee_i18ntags"));
-#else
     addDefaultLibrary(QStringLiteral("ktexttemplate_i18ntags"));
-#endif
     addDefaultLibrary(QStringLiteral("kde_grantlee_plugin"));
-    addDefaultLibrary(QStringLiteral("grantlee_scriptabletags"));
+    addDefaultLibrary(QStringLiteral("ktexttemplate_scriptabletags"));
     setSmartTrimEnabled(true);
 }
 
@@ -51,3 +43,5 @@ QSharedPointer<GrantleeKi18nLocalizer> Engine::localizer() const
     }
     return loc;
 }
+
+#include "moc_grantleethemeengine.cpp"
